# Supporting the project

If you like the project and/or use it, please consider supporting us. You can do this in different ways:
* Helping others in the [community](https://github.com/theengs/gateway/discussions)
* [Contribute](development) to the [code](https://github.com/theengs/gateway) or the documentation,
* Buy devices, boards or parts from the [compatible web site](https://compatible.openmqttgateway.com), the devices and parts linked use affiliated links,
* Donate or sponsor the project [developers](https://github.com/theengs/gateway/graphs/contributors)
* Make a video or a blog article about what you have done with [TheengsGateway](https://github.com/theengs/gateway) and share it.
